import {request} from "@/api/request";
import {Category} from "@/api/public";

export interface AdwareParams {
  key: string
  value: string

  [key: string]: string
}

export interface AdwareLinkType {
  id: number
  api_name: string
  path: string
  param: string
}

export interface AdwareType {
  image_path: string
  advert_link: AdwareLinkType
  scope_id: number | string
  id: number
  name: string
  status: 0 | 1 // 禁用
  sort: number
  image_url: string
  image_link: string
  start_time: number
  end_time?: number
}

export interface HomeData {
  adverts: AdwareType[]
  skill: VideList[]
  health: VideList[]
  brand: {
    list: Brand[]
  }
  illness: {
    list: Illness[]
  }
}

interface Course {
  articles: any[]
  audit_mode: boolean
  course: { data: Curriculum[], total: number }
}

export const HomeApi = {
  course(page: number, page_size: number) {
    return request<Course>('/home/v1/course/course', "GET", {page, page_size})
  },
  health(page: number, page_size: number) {
    return request<{ data: VideList[], total: number }>('/home/v1/health/index', "GET", {page, page_size})
  },
  /** 品牌 */
  brand(page: number, page_size: number) {
    return request<{ list: Brand[], total: number }>('/home/v1/brand/list', "GET", {page, page_size})
  },
  skillCategory() {
    return request<Category[]>('/home/v1/skill/category', "GET")
  },
  skillList(categoryId: number, page: number, page_size: number) {
    return request<{ data: VideList[], total: number }>('/home/v1/skill/index', "GET", {categoryId, page, page_size})
  },
  /** 疾病知识 */
  illness(page: number, page_size: number) {
    return request<{ list: Illness[], total: number }>('/home/v1/article/illness_list', "GET", {page, page_size})
  },
  category(type: number) {
    return request<Category[]>('/home/v1/category/index/info?type=' + type, "GET")
  },
  home() {
    return request<HomeData>('/home/v1/home/home_page', "GET", {count: 3})
  },
  /** 文章播放量 + 1 */
  articleViews(id: string | number) {
    return request(`/home/v1/article/views/${id}`, "POST")
  },
  voideView(id: number | string) {
    return request(`/home/v1/health/set_play/${id}`, "PUT")
  }
}
